View source: R/compare_mixing_2.R
| compare_mixing_2 | R Documentation |
This function provides a graphical display to compare mixing plans using a different number of revolutions based on the estimated probability of detection at the end of mixing.
compare_mixing_2(
mulower,
muupper,
sigma,
alpha_in,
k,
l,
r,
distribution,
UDL,
n_sim
)
mulower |
the lower value of the mean concentration ( |
muupper |
the upper value of the mean concentration ( |
sigma |
the standard deviation of the colony-forming units (CFUs) in the mixed sample on the logarithmic scale (default value 0.8) |
alpha_in |
concentration parameter at the initial stage |
k |
number of small portions / primary samples |
l |
number of revolutions / stages |
r |
the rate of the concentration parameter changes at each mixing stage |
distribution |
what suitable distribution type we have employed for simulation such as |
UDL |
the upper decision limit, which depends on the type of microorganisms and testing regulations. |
n_sim |
number of simulations |
graphical display compares mixing plans using a different number of revolutions based on the estimated probability of detection at the end of the mixing.
Nauta, M.J., 2005. Microbiological risk assessment models for partitioning and mixing during food handling. International Journal of Food Microbiology 100, 311-322.
sim_single_pd_stages
mulower <- 0.1
muupper <- 200
sigma <- 0.8
alpha_in <- 0.01
k <- 30
l <- c(500,5000)
r <- 0.01
distribution <- "Poisson lognormal-Type B"
UDL <- 0
n_sim <- 2000
compare_mixing_2(mulower, muupper, sigma , alpha_in, k, l, r, distribution, UDL, n_sim)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.